clear; clc

% Parameters
iess = sort([   linspace(.01,.75,10),...
                linspace(.76,.90,10),...
                linspace(.91,.997,25),...
                linspace(1.007,1.09,25),...
                linspace(1.10,1.5,10),...
                linspace(1.51,2,10),...
                .95]);
npsi = numel(iess);
P.beta = .994;
P.sigma = 80;
P.siga2 = .003^2;
P.sigsiga2 = .003;

modstrs = {'BB','DRT'};
nmod = numel(modstrs);

% Steady state
As = zeros(npsi,2);
Aas = zeros(npsi,2);
options = optimset('fsolve');
options.TolFun = 1e-6;
for ipsi = 1:npsi
    P.chi = 1/iess(ipsi);
    for imod = 1:nmod
        modstr = modstrs{imod};
        % Solve for gross return
        R = fsolve('DRTapp_fig2_grossreturn',1.05,options,P,modstr);
        if strcmp(modstr,'BB')
            Aa = 1/(P.chi*R);
            Ba = (1-P.beta)/(1-P.chi) + (1-P.beta*R)/(P.chi*R);
            thetai = 1;
        elseif strcmp(modstr,'DRT')
            Aa = -1/((1-P.beta)*P.chi*R);
            Ba = -(1-P.beta*R)/((1-P.beta)*P.chi*R);
            thetai = -P.beta/(1-P.beta);
        end
        % Impact effect of volatility shock on consumption
        As(ipsi,imod) = -(1/(2*P.chi*R))*((thetai - Aa*P.chi + (P.chi - P.sigma)*Ba)^2 ...
                - (1-P.sigma)*(P.chi-P.sigma)*Ba^2);
        % Impact effect of level shock on consumption
        Aas(ipsi,imod) = Aa;
    end
end
max(abs(As(:,2)))
%% Plot figures
saving = 'on';

set(0,'DefaultAxesFontName','Times New Roman')
set(0,'DefaultFigureUnits','inches')
set(0,'DefaultFigureRenderer','painters')
set(0,'DefaultFigurePaperPositionMode','auto')
set(0,'DefaultLineLineWidth',1)
set(0,'DefaultTextInterpreter','Latex')
figbox = [1 4.5 6.5 1.95];
plotdim = [1,2];
pad.topmarg = .1;
pad.leftmarg = .1;
pad.vspace = .2;
pad.hspace = .125;
pad.rightmarg = .02;
pad.botmarg = .2;
fontsize = 10;
colors = {[0 0 0] [0 0 1] [1 0 0] [.5 0 .5]}; 
type_line = {'-','--','--','--'};
type_mark = {'.','.','o','^'};
type_leg = {'-','--','--o','--^'};
nticks = 8;

axes = [0 2 -.05 .05;
        0 2 -.05 .05];

ylabels = {'Consumption (\%)','Consumption (\%)'};
titlestrs = {'BB Preferences','Alternative Preferences'};

figure(1);
set(gcf,'Position',figbox);
for j = 1:2
    % Set subplot and dimensions
    [col,row] = ind2sub(plotdim([2 1]),j);
    imod = col;
    width = (1-pad.leftmarg-pad.hspace*(plotdim(2)-1)-pad.rightmarg)/plotdim(2);
    height = (1-pad.topmarg-pad.vspace*(plotdim(1)-1)-pad.botmarg)/plotdim(1);
    left = pad.leftmarg + (col-1)*(width+pad.hspace);
    bottom = 1-pad.topmarg-row*height-(row-1)*pad.vspace;
    subplot(plotdim(1),plotdim(2),j,'Position',[left bottom width height]); grid on; hold on; box on;

    % Plot
    temp = As(:,imod);
    if imod == 1
        plot(iess(iess<1),temp(iess<1),'b')
        plot(iess(iess>1),temp(iess>1),'b')
        plot([1,1],axes(j,3:4),'k--')
    elseif imod == 2
        plot(iess,temp(:),'b')
    end
    plot(0.95,temp(iess==0.95),'.r','MarkerSize',15)
    xlabel('IES ($\psi$)','fontsize',fontsize)
    ylabel(ylabels{imod},'fontsize',fontsize)
    title(titlestrs{j},'fontsize',fontsize);
    axis(axes(j,:))
    set(gca,'xtick',0:.5:2,'xlim',[0,2],'ytick',-.05:.025:.05,'ylim',[-.05,.05])
end

if strcmp(saving,'on')
    savename = 'DRT Figures/fig_analytic';
    print(gcf,'-depsc2','-painters',[savename '.eps'])
    saveas(gcf,[savename '.fig'])
end